Computes the Poisson log-likelihood of an observed epidemic, compared to the expected incidence values for a given R and generation time distirbution.
fit.epid(log.R, epid, GT, import, pred = FALSE, offset = 0)The Poisson log-likelihood of the observed epidemic passed as argument epid,
or the Poisson-predicted incidence series given R and GT values.
The log-reproduction ratio.
An epidemic curve, in the sense of passing check.incid() validations. It must have at least an incidence vector in an incid component.
Generation time distribution from generation.time().
Vector of imported cases
Boolean. By default (FALSE), the function returns the corresponding log-likelihood. When set to TRUE, the function will return the Poisson-predicted incidence series instead.
Offset value for the log-likelihood (used to calculate confidence intervals).
Pierre-Yves Boelle, Thomas Obadia
For internal use. Called from est.R0.ML().
Computes and returns the Poisson log-likelihood of an observed epidemic, conditional on a given value of R and a generation time distribution.