An objective function, wrapped around fit.epid(), that will be passed to
stats::optim() to jointly estimate the best-fitting R and GT distributions
in the context of the Maximum-Likelihood method from est.R0.ML().
fit.epid.optim(par = c(1, 1, 1), ...)A Poisson log-likelihood from fit.epid().
A vector of three numerical values to be optimized, in the order c(log.R, GT$mean, GT$sd).
Parameters passed to inner functions.
Pierre-Yves Boelle, Thomas Obadia
For internal use. Called from est.R0.ML().
This is a wrapper function used to pass proper arguments to fit.epid() when
the ML method is used to estimate simultaneously R and GT. This function is
used as objective to maximize by stats::optim().