When first records of incidence are unavailable, tries to impute censored cases to rebuild a longer epidemic vector.
impute.incid(CD.optim.vect, CD.epid, CD.R0, CD.GT)A vector with both imputed incidence and source available data.
Vector of two elements (c(multiplicative factor, log(highest imputed data))) to be optimized.
Original epidemic vector, output of check.incid().
Assumed R0 value for the original epidemic vector.
Generation time distribution to be used for computations.
Pierre-Yves Boelle, Thomas Obadia
This function is not intended for stand-alone use. It optimizes the values
of vect, based upon minimization of deviation between actual epidemics data
and observed generation time. The optimized function is censored.deviation(),
which returns the deviation used for minimization. Stand-alone use can be
conducted, however this assumes data are all of the correct format.